| country | R Documentation |
This function queries the Country endpoints of the EPPO Global Database via
REST API for one or more ISO code(s) and one or more service(s). For each
ISO code in isoCodes, the function sequentially queries all specified
services and returns the extracted data through a list of dataframes.
country(
isoCodes,
services = c("overview", "categorization", "presence"),
apiKey = Sys.getenv("EPPO_API_KEY")
)
isoCodes |
ISO country codes are standardized identifiers for countries and territories. These codes, typically consisting of two-letter, provide unique and consistent abbreviations of country names. The ISO coding system enables easy management, exchange, and integration of country information across databases and IT systems. ISO country codes and their related data can be accessed via the ISO Online Browsing Platform. |
services |
By default: all services. |
apiKey |
By default: Sys.getenv("EPPO_API_KEY"). |
A named list of results, in which each level corresponds to the data retrieved for each specified service. Each service element contains a flattened dataframe with the queried content for all the specified ISO codes.
## Not run:
# Get all information about France.
countryData_ <- country(isoCodes = c("FR"))
# Get categorization data about France.
countryData_ <- country(isoCodes = c("FR"), services = c("categorization"))
# Get basic data about France and Italy.
countryData_ <- country(isoCodes = c("FR", "IT"), services = c("overview"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.