eppoFindeR-package: eppoFindeR: Interface to the EPPO Database and Public APIs

eppoFindeR-packageR Documentation

eppoFindeR: Interface to the EPPO Database and Public APIs

Description

logo

Provides an interface to the public APIs of the European and Mediterranean Plant Protection Organization (EPPO) database. It enables users to retrieve EPPO data by accessing specific services and datasets. The package also includes utilities for data wrangling, including the integration of taxonomy with rank information. See https://data.eppo.int/apis/ for more details.

Author(s)

Maintainer: Luca Belmonte luca.belmonte@efsa.europa.eu (ORCID)

Authors:

  • Lorenzo Copelli (ORCID)

  • Dayana Stephanie Buzle (ORCID)

  • Rafael Vieira (ORCID)

  • Agata Kaczmarek (ORCID)

See Also

Useful links:


eppoFindeR documentation built on April 25, 2026, 1:07 a.m.