| rppo | R Documentation |
This function queries the RPPO endpoints of the EPPO Global Database via
REST API for one or more RPPO code(s) and one or more service(s). For each
RPPO code in rppoCodes, the function sequentially queries all specified
services and returns the extracted data through a list of dataframes.
rppo(
rppoCodes,
services = c("overview", "categorization"),
apiKey = Sys.getenv("EPPO_API_KEY")
)
rppoCodes |
|
services |
By default: all services. |
apiKey |
By default: Sys.getenv("EPPO_API_KEY"). |
A named list of results, in which each level corresponds to the data retrieved for each specified service. Each service element contains a flattened dataframe with the queried content for all the specified RPPO codes.
## Not run:
# Get all information about the European and Mediterranean Plant Protection
# Organisation.
rppoData_ <- rppo(rppoCodes = c("9A"))
# Get categorization data about the European and Mediterranean Plant
# Protection Organisation.
rppoData_ <- rppo(rppoCodes = c("9A"), services = c("categorization"))
# Get basic data about European and Mediterranean Plant Protection
# Organisation and the European Union.
rppoData_ <- rppo(rppoCodes = c("9A", "9L"), services = c("overview"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.