| eppoFindeR-package | R Documentation |
Provides an interface to the public APIs of the European and Mediterranean Plant Protection Organization (EPPO) database. It enables users to retrieve EPPO data by accessing specific services and datasets. The package also includes utilities for data wrangling, including the integration of taxonomy with rank information. See https://data.eppo.int/apis/ for more details.
Maintainer: Luca Belmonte luca.belmonte@efsa.europa.eu (ORCID)
Authors:
Lorenzo Copelli (ORCID)
Dayana Stephanie Buzle (ORCID)
Rafael Vieira (ORCID)
Agata Kaczmarek (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.