| references | R Documentation |
This function queries the References endpoints of the EPPO Global Database
via REST API. The function sequentially queries all specified services and
returns the extracted data through a list of dataframes.
references(
services = c("rppos", "qList", "distributionStatus", "pestHostClassification",
"vectorClassification", "countries", "countriesStates"),
apiKey = Sys.getenv("EPPO_API_KEY")
)
services |
By default: all services. |
apiKey |
By default: Sys.getenv("EPPO_API_KEY"). |
A named list of results, in which each level corresponds to the data retrieved for each specified service. Each service element contains a flattened dataframe with the queried content.
## Not run:
# Get all information.
referencesData_ <- references()
# Get information about distribution status codes.
referencesData_ <- references(services = c("distributionStatus"))
# Get information about EPPO list codes and labels and countries.
referencesData_ <- references(services = c("qList", "countries"))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.