View source: R/reportingService.R
| reportingService | R Documentation |
This function queries the Taxons endpoints of the EPPO Global Database via
REST API. The function sequentially queries all specified services and
returns the extracted data through a list of dataframes.
reportingService(
services = c("list", "reporting", "article"),
params = list(list = list(), reporting = list(), article = list()),
apiKey = Sys.getenv("EPPO_API_KEY")
)
services |
By default: all services. |
params |
By default: no parameters, you need to specify the required ones. |
apiKey |
By default: Sys.getenv("EPPO_API_KEY"). |
A named list of results, in which each level corresponds to the data retrieved for each specified service. Each service element contains a flattened dataframe with the queried content.
## Not run:
# Get the list of reporting service issues.
reportingServiceData_ <- reportingService(
services = c("list"),
params = list(
"list" = list()))
# Get a specific reporting service issue by ID.
reportingServiceData_ <- reportingService(
services = c("reporting"),
params = list(
reporting = list(
reporting_id = 10)))
# Get a specific article by ID.
reportingServiceData_ <- reportingService(
services = c("article"),
params = list(
article = list(
article_id = 234)))
# Get a specific reporting service issue and a specific article by ID.
reportingServiceData_ <- reportingService(
services = c("reporting", "article"),
params = list(
reporting = list(reporting_id = 10),
article = list(article_id = 234)
))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.