| taxons | R Documentation |
This function queries the Taxons endpoints of the EPPO Global Database via
REST API. The function sequentially queries all specified services and
returns the extracted data through a list of dataframes.
taxons(
services = c("list"),
params = list(list = list(limit = 100, offset = 0, orderAsc = TRUE, orderBy =
"creation")),
apiKey = Sys.getenv("EPPO_API_KEY")
)
services |
By default: all services. |
params |
By default: default parameters. |
apiKey |
By default: Sys.getenv("EPPO_API_KEY"). |
A named list of results, in which each level corresponds to the data retrieved for each specified service. Each service element contains a flattened dataframe with the queried content.
## Not run:
# Get the list of taxons.
taxonsData_ <- taxons()
# Get the list of taxons with custom parameters.
taxonsData_ <- taxons(params = list(
"list" = list(
createdFromDate = "2000-01-01",
limit = 5,
offset = 1,
orderAsc = FALSE,
orderBy = "eppocode")))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.