| tools | R Documentation |
This function queries the Tools endpoints of the EPPO Global Database via
REST API. The function sequentially queries all specified services and
returns the extracted data through a list of dataframes.
tools(
services = c("name2codes"),
params = list(name2codes = list()),
apiKey = Sys.getenv("EPPO_API_KEY")
)
services |
By default: all services. |
params |
By default: no parameters, you need to specify the required ones. |
apiKey |
By default: Sys.getenv("EPPO_API_KEY"). |
A named list of results, in which each level corresponds to the data retrieved for each specified service. Each service element contains a flattened dataframe with the queried content.
## Not run:
# Get the EPPO codes associated to the name Bemisia tabaci.
toolsData_ <- tools(params = list(
name2codes = list(
onlyPreferred = FALSE,
name = "Bemisia tabaci")))
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.